@@ -18,5 +18,11 @@ elif chip_id == ap_chip.SUN8I:
     from adafruit_blinka.microcontroller.allwinner_h3.pin import *
 elif chip_id == ap_chip.SAMA5:
     from adafruit_blinka.microcontroller.sama5.pin import *
+elif chip_id == ap_chip.T210:
+    from adafruit_blinka.microcontroller.tegra.t210.pin import *
+elif chip_id == ap_chip.T186:
+    from adafruit_blinka.microcontroller.tegra.t186.pin import *
+elif chip_id == ap_chip.T194:
+    from adafruit_blinka.microcontroller.tegra.t194.pin import *
 else:
     raise NotImplementedError("Microcontroller not supported: ", chip_id)
